==> zio-aws-route53resolver_2.13-5.17.146.1-sources.jar: zio/aws/route53resolver/model/AssociateResolverQueryLogConfigResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AssociateResolverQueryLogConfigResponse(
    resolverQueryLogConfigAssociation: Option[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse = {
    import AssociateResolverQueryLogConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
      .builder()
      .optionallyWith(
        resolverQueryLogConfigAssociation.map(value => value.buildAwsValue())
      )(_.resolverQueryLogConfigAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly =
    zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse
      .wrap(buildAwsValue())
}
object AssociateResolverQueryLogConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse =
      zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse(
        resolverQueryLogConfigAssociation.map(value => value.asEditable)
      )
    def resolverQueryLogConfigAssociation: Option[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ]
    def getResolverQueryLogConfigAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverQueryLogConfigAssociation",
      resolverQueryLogConfigAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ) extends zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly {
    override val resolverQueryLogConfigAssociation: Option[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ] = scala
      .Option(impl.resolverQueryLogConfigAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ): zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53resolver_2.13-5.17.197.2-sources.jar: zio/aws/route53resolver/model/AssociateResolverQueryLogConfigResponse.scala <==
package zio.aws.route53resolver.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AssociateResolverQueryLogConfigResponse(
    resolverQueryLogConfigAssociation: Optional[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse = {
    import AssociateResolverQueryLogConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
      .builder()
      .optionallyWith(
        resolverQueryLogConfigAssociation.map(value => value.buildAwsValue())
      )(_.resolverQueryLogConfigAssociation)
      .build()
  }
  def asReadOnly
      : zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly =
    zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse
      .wrap(buildAwsValue())
}
object AssociateResolverQueryLogConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse =
      zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse(
        resolverQueryLogConfigAssociation.map(value => value.asEditable)
      )
    def resolverQueryLogConfigAssociation: Optional[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ]
    def getResolverQueryLogConfigAssociation: ZIO[
      Any,
      AwsError,
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ] = AwsError.unwrapOptionField(
      "resolverQueryLogConfigAssociation",
      resolverQueryLogConfigAssociation
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ) extends zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly {
    override val resolverQueryLogConfigAssociation: Optional[
      zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.resolverQueryLogConfigAssociation())
      .map(value =>
        zio.aws.route53resolver.model.ResolverQueryLogConfigAssociation
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53resolver.model.AssociateResolverQueryLogConfigResponse
  ): zio.aws.route53resolver.model.AssociateResolverQueryLogConfigResponse.ReadOnly =
    new Wrapper(impl)
}
